<?php

/**
 * Handles requests for site settings
 */
class SiteSettingsController extends SiteSettingsAppController {

	/**
	 * Defines the buttons displayed on the admin toolbar
	 */
	protected function _adminIndexToolbar() {

		$user = $this->Auth->user();
		if ($user['User']['user_group_id'] == 1) {

			return array(
				'Add New Setting' => array(
					'url' => array('action' => 'add')
				)
			);
		} else {

			return;
		}
	}

	/**
	 * Landing Page - Edit Site settings
	 *
	 * Site settings are handled differently from other models
	 * This screen is a combined index & edit
	 */
	public function admin_index() {

		$fields = array();

		$data = $this->SiteSetting->find('grouped', array(
			'order' => array(
				'SiteSettingCategory.sequence' => 'ASC',
				'SiteSetting.sequence' => 'ASC',
				'SiteSetting.name' => 'ASC'
			)
		));

		// build up a field list to display the settings
		foreach ($data as $categoryName => $category) {

			foreach ($category as $setting) {

				$fields[$categoryName]['SiteSetting.' . $setting['SiteSetting']['id'] . '.' . $setting['SiteSetting']['name']] = array(
					'type' => $setting['SiteSetting']['type'],
					'label' => $setting['SiteSetting']['label'] != "" ? $setting['SiteSetting']['label'] : $setting['SiteSetting']['name']
				);
			}
		}

		// handle a form post
		if (!empty($this->request->data)) {

			foreach ($this->request->data['SiteSetting'] as $id => $attr) {

				// Skip any non-numeric keys
				if (!is_numeric($id)) {
					continue;
				}

				$value = array_pop($attr);
				$this->SiteSetting->save(array(
					'SiteSetting' => array(
						'id' => $id,
						'value' => $value
					)
				));
			}

			$this->set('settings_saved', true);
		} else {

			foreach ($data as $category) {

				foreach ($category as $setting) {

					$this->request->data['SiteSetting'][$setting['SiteSetting']['id']][$setting['SiteSetting']['name']] = $setting['SiteSetting']['value'];
				}
			}
		}

		$this->set('fields', $fields);

		$this->set('toolbar', $this->_adminIndexToolbar());

		$this->set('title_for_layout', 'Site Settings');

		$this->render('admin_form');
	}

	protected function _adminPopulateLookups() {

		$siteSettingCategories = $this->SiteSetting->SiteSettingCategory->find('list');

		$this->set(compact('siteSettingCategories'));
	}

}
